@@ -3,7 +3,8 @@
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD license.
-# However, when used with the GPL version of PyQt the additional terms described in the PyQt GPL exception also apply
+# However, when used with the GPL version of PyQt the additional terms
+# described in the PyQt GPL exception also apply
 
 #
 # Author: Riverbank Computing Limited
@@ -23,5 +24,5 @@ import pyface.qt
 
 import toolkit
 
-# Reference to the GUIToolkit object for PyQt.
-toolkit = toolkit.GUIToolkit()
+# Reference to the GUIToolkit object for Qt.
+toolkit = toolkit.GUIToolkit('traitsui', 'qt4', 'traitsui.qt4')
