@@ -19,9 +19,9 @@
     wxPython user interface toolkit.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 import wx
 
@@ -40,74 +40,82 @@ from editor \
 from helper \
     import TraitsUIPanel
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'CompoundEditor' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class CompoundEditor ( Editor ):
+
+class CompoundEditor(Editor):
     """ Editor for compound traits, which displays editors for each of the
     combined traits, in the appropriate style.
     """
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Trait definitions:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     # The kind of editor to create for each list item
     kind = Str
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Finishes initializing the editor by creating the underlying toolkit
     #  widget:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def init ( self, parent ):
+    def init(self, parent):
         """ Finishes initializing the editor by creating the underlying toolkit
             widget.
         """
         # Create a panel to hold all of the component trait editors:
-        self.control = panel = TraitsUIPanel( parent, -1 )
-        sizer        = wx.BoxSizer( wx.VERTICAL )
+        self.control = panel = TraitsUIPanel(parent, -1)
+        sizer = wx.BoxSizer(wx.VERTICAL)
 
         # Add all of the component trait editors:
         self._editors = editors = []
         for factory in self.factory.editors:
-            editor = getattr( factory, self.kind )( self.ui, self.object,
-                                       self.name, self.description, panel )
-            editor.prepare( panel )
-            sizer.Add( editor.control, 1,
-                       wx.TOP | wx.BOTTOM | editor.layout_style, 3 )
-            editors.append( editor )
+            editor = getattr(
+                factory,
+                self.kind)(
+                self.ui,
+                self.object,
+                self.name,
+                self.description,
+                panel)
+            editor.prepare(panel)
+            sizer.Add(editor.control, 1,
+                      wx.TOP | wx.BOTTOM | editor.layout_style, 3)
+            editors.append(editor)
 
         # Set-up the layout:
-        panel.SetSizerAndFit( sizer )
+        panel.SetSizerAndFit(sizer)
 
         self.set_tooltip()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Updates the editor when the object trait changes external to the editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def update_editor ( self ):
+    def update_editor(self):
         """ Updates the editor when the object trait changes externally to the
             editor.
         """
         pass
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Disposes of the contents of an editor:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def dispose ( self ):
+    def dispose(self):
         """ Disposes of the contents of an editor.
         """
         for editor in self._editors:
             editor.dispose()
 
-        super( CompoundEditor, self ).dispose()
+        super(CompoundEditor, self).dispose()
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'SimpleEditor' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
 
 class SimpleEditor(CompoundEditor):
 
@@ -115,9 +123,10 @@ class SimpleEditor(CompoundEditor):
     # the default.
     kind = 'simple_editor'
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'CustomEditor' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
+
 
 class CustomEditor(CompoundEditor):
 
