@@ -19,170 +19,158 @@
     the wxPython user interface toolkit.
 """
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Imports:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 # Make sure that importimg from this backend is OK:
 from traitsui.toolkit import assert_toolkit_import
-assert_toolkit_import('wx')
+assert_toolkit_import(['wx'])
 
 import wx
 
-# Make sure a wx.App object is created early:
-_app = wx.GetApp()
-if _app is None:
-    _app = wx.App(redirect=False)
+# Ensure that we can import Pyface backend.  This starts App as a side-effect.
+from pyface.toolkit import toolkit_object as pyface_toolkit
+_app = pyface_toolkit('init:_app')
 
-from traits.api \
-    import HasPrivateTraits, Instance, Property, Category, cached_property
+from traits.api import (
+    HasPrivateTraits, Instance, Property, Category, cached_property
+)
+from traits.trait_notifiers import set_ui_handler
+from pyface.wx.drag_and_drop import PythonDropTarget
 
-from traits.trait_notifiers \
-    import set_ui_handler
+from traitsui.theme import Theme
+from traitsui.ui import UI
+from traitsui.dock_window_theme import DockWindowTheme
+from traitsui.toolkit import Toolkit
 
-from traitsui.ui \
-    import UI
+from .constants import WindowColor, screen_dx, screen_dy
+from .helper import position_window
 
-from traitsui.theme \
-    import Theme
-
-from traitsui.dock_window_theme \
-    import DockWindowTheme
-
-from traitsui.toolkit \
-    import Toolkit
-
-from pyface.wx.drag_and_drop \
-    import PythonDropTarget
-
-from constants \
-    import WindowColor, screen_dx, screen_dy
-
-from helper \
-    import position_window
-
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Constants:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 EventSuffix = {
-    wx.wxEVT_LEFT_DOWN:     'left_down',
-    wx.wxEVT_LEFT_DCLICK:   'left_dclick',
-    wx.wxEVT_LEFT_UP:       'left_up',
-    wx.wxEVT_MIDDLE_DOWN:   'middle_down',
+    wx.wxEVT_LEFT_DOWN: 'left_down',
+    wx.wxEVT_LEFT_DCLICK: 'left_dclick',
+    wx.wxEVT_LEFT_UP: 'left_up',
+    wx.wxEVT_MIDDLE_DOWN: 'middle_down',
     wx.wxEVT_MIDDLE_DCLICK: 'middle_dclick',
-    wx.wxEVT_MIDDLE_UP:     'middle_up',
-    wx.wxEVT_RIGHT_DOWN:    'right_down',
-    wx.wxEVT_RIGHT_DCLICK:  'right_dclick',
-    wx.wxEVT_RIGHT_UP:      'right_up',
-    wx.wxEVT_MOTION:        'mouse_move',
-    wx.wxEVT_ENTER_WINDOW:  'enter',
-    wx.wxEVT_LEAVE_WINDOW:  'leave',
-    wx.wxEVT_MOUSEWHEEL:    'mouse_wheel',
-    wx.wxEVT_PAINT:         'paint',
+    wx.wxEVT_MIDDLE_UP: 'middle_up',
+    wx.wxEVT_RIGHT_DOWN: 'right_down',
+    wx.wxEVT_RIGHT_DCLICK: 'right_dclick',
+    wx.wxEVT_RIGHT_UP: 'right_up',
+    wx.wxEVT_MOTION: 'mouse_move',
+    wx.wxEVT_ENTER_WINDOW: 'enter',
+    wx.wxEVT_LEAVE_WINDOW: 'leave',
+    wx.wxEVT_MOUSEWHEEL: 'mouse_wheel',
+    wx.wxEVT_PAINT: 'paint',
 }
 
 # Types of popup views:
-Popups = set( ( 'popup', 'popover', 'info' ) )
+Popups = set(('popup', 'popover', 'info'))
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  Handles UI notification handler requests that occur on a thread other than
 #  the UI thread:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-def ui_handler ( handler, *args ):
+
+def ui_handler(handler, *args):
     """ Handles UI notification handler requests that occur on a thread other
         than the UI thread.
     """
-    wx.CallAfter( handler, *args )
+    wx.CallAfter(handler, *args)
 
 # Tell the traits notification handlers to use this UI handler
-set_ui_handler( ui_handler )
+set_ui_handler(ui_handler)
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'GUIToolkit' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class GUIToolkit ( Toolkit ):
+
+class GUIToolkit(Toolkit):
     """ Implementation class for wxPython toolkit.
     """
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Create wxPython specific user interfaces using information from the
     #  specified UI object:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def ui_panel ( self, ui, parent ):
+    def ui_panel(self, ui, parent):
         """ Creates a wxPython panel-based user interface using information
             from the specified UI object.
         """
         import ui_panel
-        ui_panel.ui_panel( ui, parent )
+        ui_panel.ui_panel(ui, parent)
 
-    def ui_subpanel ( self, ui, parent ):
+    def ui_subpanel(self, ui, parent):
         """ Creates a wxPython subpanel-based user interface using information
             from the specified UI object.
         """
         import ui_panel
-        ui_panel.ui_subpanel( ui, parent )
+        ui_panel.ui_subpanel(ui, parent)
 
-    def ui_livemodal ( self, ui, parent ):
+    def ui_livemodal(self, ui, parent):
         """ Creates a wxPython modal "live update" dialog user interface using
             information from the specified UI object.
         """
         import ui_live
-        ui_live.ui_livemodal( ui, parent )
+        ui_live.ui_livemodal(ui, parent)
 
-    def ui_live ( self, ui, parent ):
+    def ui_live(self, ui, parent):
         """ Creates a wxPython non-modal "live update" window user interface
             using information from the specified UI object.
         """
         import ui_live
-        ui_live.ui_live( ui, parent )
+        ui_live.ui_live(ui, parent)
 
-    def ui_modal ( self, ui, parent ):
+    def ui_modal(self, ui, parent):
         """ Creates a wxPython modal dialog user interface using information
             from the specified UI object.
         """
         import ui_modal
-        ui_modal.ui_modal( ui, parent )
+        ui_modal.ui_modal(ui, parent)
 
-    def ui_nonmodal ( self, ui, parent ):
+    def ui_nonmodal(self, ui, parent):
         """ Creates a wxPython non-modal dialog user interface using
             information from the specified UI object.
         """
         import ui_modal
-        ui_modal.ui_nonmodal( ui, parent )
+        ui_modal.ui_nonmodal(ui, parent)
 
-    def ui_popup ( self, ui, parent ):
+    def ui_popup(self, ui, parent):
         """ Creates a wxPython temporary "live update" popup dialog user
             interface using information from the specified UI object.
         """
         import ui_live
-        ui_live.ui_popup( ui, parent )
+        ui_live.ui_popup(ui, parent)
 
-    def ui_popover ( self, ui, parent ):
+    def ui_popover(self, ui, parent):
         """ Creates a wxPython temporary "live update" popup dialog user
             interface using information from the specified UI object.
         """
         import ui_live
-        ui_live.ui_popover( ui, parent )
+        ui_live.ui_popover(ui, parent)
 
-    def ui_info ( self, ui, parent ):
+    def ui_info(self, ui, parent):
         """ Creates a wxPython temporary "live update" popup dialog user
             interface using information from the specified UI object.
         """
         import ui_live
-        ui_live.ui_info( ui, parent )
+        ui_live.ui_info(ui, parent)
 
-    def ui_wizard ( self, ui, parent ):
+    def ui_wizard(self, ui, parent):
         """ Creates a wxPython wizard dialog user interface using information
             from the specified UI object.
         """
         import ui_wizard
-        ui_wizard.ui_wizard( ui, parent )
+        ui_wizard.ui_wizard(ui, parent)
 
-    def view_application ( self, context, view, kind = None, handler = None,
-                                     id = '', scrollable = None, args = None ):
+    def view_application(self, context, view, kind=None, handler=None,
+                         id='', scrollable=None, args=None):
         """ Creates a wxPython modal dialog user interface that
             runs as a complete application, using information from the
             specified View object.
@@ -215,49 +203,49 @@ class GUIToolkit ( Toolkit ):
 
         """
         import view_application
-        return view_application.view_application( context, view, kind, handler,
-                                                  id, scrollable, args )
+        return view_application.view_application(context, view, kind, handler,
+                                                 id, scrollable, args)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Positions the associated dialog window on the display:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def position ( self, ui ):
+    def position(self, ui):
         """ Positions the associated dialog window on the display.
         """
-        view   = ui.view
+        view = ui.view
         window = ui.control
 
         # Set up the default position of the window:
         parent = window.GetParent()
         if parent is None:
-           px,  py  = 0, 0
-           pdx, pdy = screen_dx, screen_dy
+            px, py = 0, 0
+            pdx, pdy = screen_dx, screen_dy
         else:
-           px,  py  = parent.GetPositionTuple()
-           pdx, pdy = parent.GetSizeTuple()
+            px, py = parent.GetPositionTuple()
+            pdx, pdy = parent.GetSizeTuple()
 
         # Calculate the correct width and height for the window:
         cur_width, cur_height = window.GetSizeTuple()
-        width  = view.width
+        width = view.width
         height = view.height
 
         if width < 0.0:
             width = cur_width
         elif width <= 1.0:
-            width = int( width * screen_dx )
+            width = int(width * screen_dx)
         else:
-            width = int( width )
+            width = int(width)
 
         if height < 0.0:
             height = cur_height
         elif height <= 1.0:
-            height = int( height * screen_dy )
+            height = int(height * screen_dy)
         else:
-            height = int( height )
+            height = int(height)
 
         if view.kind in Popups:
-            position_window( window, width, height )
+            position_window(window, width, height)
             return
 
         # Calculate the correct position for the window:
@@ -268,33 +256,33 @@ class GUIToolkit ( Toolkit ):
             # BH- I think this is the case when there is a parent
             # so this logic tries to place it in the middle of the parent
             # if possible, otherwise tries an offset from the parent
-            x = px + (pdx - width)/2
+            x = px + (pdx - width) / 2
             if x < 0:
-                 x = px + 20
+                x = px + 20
         elif x <= -1.0:
-            x = px + pdx - width + int( x ) + 1
+            x = px + pdx - width + int(x) + 1
         elif x < 0.0:
-            x = px + pdx - width + int( x * pdx )
+            x = px + pdx - width + int(x * pdx)
         elif x <= 1.0:
-            x = px + int( x * pdx )
+            x = px + int(x * pdx)
         else:
-            x = int( x )
+            x = int(x)
 
         if y < -99999.0:
             # BH- I think this is the case when there is a parent
             # so this logic tries to place it in the middle of the parent
             # if possible, otherwise tries an offset from the parent
-            y = py + (pdy - height)/2
+            y = py + (pdy - height) / 2
             if y < 0:
                 y = py + 20
         elif y <= -1.0:
-            y = py + pdy - height + int( y ) + 1
+            y = py + pdy - height + int(y) + 1
         elif x < 0.0:
-            y = py + pdy - height + int( y * pdy )
+            y = py + pdy - height + int(y * pdy)
         elif y <= 1.0:
-            y = py + int( y * pdy )
+            y = py + int(y * pdy)
         else:
-            y = int( y )
+            y = int(y)
 
         # make sure the position is on the visible screen, maybe
         # the desktop had been resized?
@@ -302,173 +290,180 @@ class GUIToolkit ( Toolkit ):
         y = min(y, wx.DisplaySize()[1])
 
         # Position and size the window as requested:
-        window.SetDimensions( max( 0, x ), max( 0, y ), width, height )
+        window.SetDimensions(max(0, x), max(0, y), width, height)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Shows a 'Help' window for a specified UI and control:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def show_help ( self, ui, control ):
+    def show_help(self, ui, control):
         """ Shows a help window for a specified UI and control.
         """
         import ui_panel
-        ui_panel.show_help( ui, control )
+        ui_panel.show_help(ui, control)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Saves user preference information associated with a UI window:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def save_window ( self, ui ):
+    def save_window(self, ui):
         """ Saves user preference information associated with a UI window.
         """
         import helper
 
-        helper.save_window( ui )
+        helper.save_window(ui)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Rebuilds a UI after a change to the content of the UI:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def rebuild_ui ( self, ui ):
+    def rebuild_ui(self, ui):
         """ Rebuilds a UI after a change to the content of the UI.
         """
         parent = size = None
 
         if ui.control is not None:
-            size   = ui.control.GetSize()
+            size = ui.control.GetSize()
             parent = ui.control._parent
             info = ui.info
             ui.recycle()
-            ui.info= info
+            ui.info = info
             info.ui = ui
 
-        ui.rebuild( ui, parent )
+        ui.rebuild(ui, parent)
 
         if parent is not None:
-            ui.control.SetSize( size )
+            ui.control.SetSize(size)
             sizer = parent.GetSizer()
             if sizer is not None:
-                sizer.Add( ui.control, 1, wx.EXPAND )
+                sizer.Add(ui.control, 1, wx.EXPAND)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Sets the title for the UI window:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def set_title ( self, ui ):
+    def set_title(self, ui):
         """ Sets the title for the UI window.
         """
-        ui.control.SetTitle( ui.title )
+        ui.control.SetTitle(ui.title)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Sets the icon for the UI window:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def set_icon ( self, ui ):
+    def set_icon(self, ui):
         """ Sets the icon for the UI window.
         """
         from pyface.image_resource import ImageResource
 
-        if isinstance( ui.icon, ImageResource ):
-            ui.control.SetIcon( ui.icon.create_icon() )
+        if isinstance(ui.icon, ImageResource):
+            ui.control.SetIcon(ui.icon.create_icon())
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Converts a keystroke event into a corresponding key name:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def key_event_to_name ( self, event ):
+    def key_event_to_name(self, event):
         """ Converts a keystroke event into a corresponding key name.
         """
         import key_event_to_name
 
-        return key_event_to_name.key_event_to_name( event )
+        return key_event_to_name.key_event_to_name(event)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Hooks all specified events for all controls in a ui so that they can be
     #  routed to the correct event handler:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def hook_events ( self, ui, control, events = None, handler = None,
-                      drop_target = None ):
+    def hook_events(self, ui, control, events=None, handler=None):
         """ Hooks all specified events for all controls in a UI so that they
             can be routed to the correct event handler.
         """
         if events is None:
             events = (
-               wx.wxEVT_LEFT_DOWN, wx.wxEVT_LEFT_DCLICK, wx.wxEVT_LEFT_UP,
-               wx.wxEVT_MIDDLE_DOWN, wx.wxEVT_MIDDLE_DCLICK, wx.wxEVT_MIDDLE_UP,
-               wx.wxEVT_RIGHT_DOWN, wx.wxEVT_RIGHT_DCLICK, wx.wxEVT_RIGHT_UP,
-               wx.wxEVT_MOTION, wx.wxEVT_ENTER_WINDOW, wx.wxEVT_LEAVE_WINDOW,
-               wx.wxEVT_MOUSEWHEEL, wx.wxEVT_PAINT
-            )
-            control.SetDropTarget( PythonDropTarget(
-                                   DragHandler( ui = ui, control = control ) ) )
+                wx.wxEVT_LEFT_DOWN,
+                wx.wxEVT_LEFT_DCLICK,
+                wx.wxEVT_LEFT_UP,
+                wx.wxEVT_MIDDLE_DOWN,
+                wx.wxEVT_MIDDLE_DCLICK,
+                wx.wxEVT_MIDDLE_UP,
+                wx.wxEVT_RIGHT_DOWN,
+                wx.wxEVT_RIGHT_DCLICK,
+                wx.wxEVT_RIGHT_UP,
+                wx.wxEVT_MOTION,
+                wx.wxEVT_ENTER_WINDOW,
+                wx.wxEVT_LEAVE_WINDOW,
+                wx.wxEVT_MOUSEWHEEL,
+                wx.wxEVT_PAINT)
+            control.SetDropTarget(PythonDropTarget(
+                DragHandler(ui=ui, control=control)))
         elif events == 'keys':
-            events = ( wx.wxEVT_CHAR, )
+            events = (wx.wxEVT_CHAR, )
 
         if handler is None:
             handler = ui.route_event
 
-        id            = control.GetId()
+        id = control.GetId()
         event_handler = EventHandlerWrapper()
-        connect       = event_handler.Connect
+        connect = event_handler.Connect
 
         for event in events:
-            connect( id, id, event, handler )
+            connect(id, id, event, handler)
 
-        control.PushEventHandler( event_handler )
+        control.PushEventHandler(event_handler)
 
         for child in control.GetChildren():
-            self.hook_events( ui, child, events, handler, drop_target )
+            self.hook_events(ui, child, events, handler)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Routes a 'hooked' event to the correct handler method:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def route_event ( self, ui, event ):
+    def route_event(self, ui, event):
         """ Routes a hooked event to the correct handler method.
         """
-        suffix  = EventSuffix[ event.GetEventType() ]
+        suffix = EventSuffix[event.GetEventType()]
         control = event.GetEventObject()
         handler = ui.handler
-        method  = None
+        method = None
 
-        owner   = getattr( control, '_owner', None )
+        owner = getattr(control, '_owner', None)
         if owner is not None:
-            method = getattr( handler, 'on_%s_%s' % ( owner.get_id(), suffix ),
-                              None )
+            method = getattr(handler, 'on_%s_%s' % (owner.get_id(), suffix),
+                             None)
 
         if method is None:
-            method = (getattr( handler, 'on_%s' % suffix, None ) or
-                      getattr( handler, 'on_any_event',   None ))
+            method = (getattr(handler, 'on_%s' % suffix, None) or
+                      getattr(handler, 'on_any_event', None))
 
-        if (method is None) or (method( ui.info, owner, event ) is False):
+        if (method is None) or (method(ui.info, owner, event) is False):
             event.Skip()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Indicates that an event should continue to be processed by the toolkit
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def skip_event ( self, event ):
+    def skip_event(self, event):
         """ Indicates that an event should continue to be processed by the
             toolkit.
         """
         event.Skip()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Destroys a specified GUI toolkit control:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def destroy_control ( self, control ):
+    def destroy_control(self, control):
         """ Destroys a specified GUI toolkit control.
         """
         _popEventHandlers(control)
         control.Destroy()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Destroys all of the child controls of a specified GUI toolkit control:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def destroy_children ( self, control ):
+    def destroy_children(self, control):
         """ Destroys all of the child controls of a specified GUI toolkit
             control.
         """
@@ -476,22 +471,22 @@ class GUIToolkit ( Toolkit ):
             _popEventHandlers(child)
         control.DestroyChildren()
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns a ( width, height ) tuple containing the size of a specified
     #  toolkit image:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def image_size ( self, image ):
+    def image_size(self, image):
         """ Returns a ( width, height ) tuple containing the size of a
             specified toolkit image.
         """
-        return ( image.GetWidth(), image.GetHeight() )
+        return (image.GetWidth(), image.GetHeight())
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Returns a dictionary of useful constants:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def constants ( self ):
+    def constants(self):
         """ Returns a dictionary of useful constants.
 
             Currently, the dictionary should have the following key/value pairs:
@@ -503,40 +498,28 @@ class GUIToolkit ( Toolkit ):
             'WindowColor': WindowColor
         }
 
-    #---------------------------------------------------------------------------
-    #  Returns a renderer used to render 'themed' table cells for a specified
-    #  TableColumn object:
-    #---------------------------------------------------------------------------
-
-    def themed_cell_renderer ( self, column ):
-        """ Returns a renderer used to render 'themed' table cells for a
-            specified TableColum object.
-        """
-        from themed_cell_renderer import ThemedCellRenderer
-        return ThemedCellRenderer( column )
-
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  GUI toolkit dependent trait definitions:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def color_trait ( self, *args, **traits ):
+    def color_trait(self, *args, **traits):
         import color_trait as ct
-        return ct.WxColor( *args, **traits )
+        return ct.WxColor(*args, **traits)
 
-    def rgb_color_trait ( self, *args, **traits ):
+    def rgb_color_trait(self, *args, **traits):
         import rgb_color_trait as rgbct
-        return rgbct.RGBColor( *args, **traits )
+        return rgbct.RGBColor(*args, **traits)
 
-    def font_trait ( self, *args, **traits ):
+    def font_trait(self, *args, **traits):
         import font_trait as ft
-        return ft.WxFont( *args, **traits )
+        return ft.WxFont(*args, **traits)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  'Editor' class methods:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     # Generic UI-base editor:
-    def ui_editor ( self ):
+    def ui_editor(self):
         import ui_editor
         return ui_editor.UIEditor
 #
@@ -596,9 +579,10 @@ class GUIToolkit ( Toolkit ):
 #        return se.ScrubberEditor( *args, **traits )
 #
 #    # Shell:
-    def shell_editor ( self, *args, **traits ):
+
+    def shell_editor(self, *args, **traits):
         import shell_editor as se
-        return se.ToolkitEditorFactory( *args, **traits )
+        return se.ToolkitEditorFactory(*args, **traits)
 #
 #    # Tabular:
 #    def tabular_editor ( self, *args, **traits ):
@@ -610,89 +594,92 @@ class GUIToolkit ( Toolkit ):
 #        import value_editor as ve
 #        return ve.ToolkitEditorFactory( *args, **traits )
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 #  'DragHandler' class:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class DragHandler ( HasPrivateTraits ):
+
+class DragHandler(HasPrivateTraits):
     """ Handler for drag events.
     """
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Traits definitions:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
     # The UI associated with the drag handler
-    ui = Instance( UI )
+    ui = Instance(UI)
 
     # The wx control associated with the drag handler
-    control = Instance( wx.Window )
+    control = Instance(wx.Window)
 
-#-- Drag and drop event handlers: ----------------------------------------------
+#-- Drag and drop event handlers: ----------------------------------------
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles a Python object being dropped on the control:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def wx_dropped_on ( self, x, y, data, drag_result ):
+    def wx_dropped_on(self, x, y, data, drag_result):
         """ Handles a Python object being dropped on the window.
         """
-        return self._drag_event( 'dropped_on', x, y, data, drag_result )
+        return self._drag_event('dropped_on', x, y, data, drag_result)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles a Python object being dragged over the control:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def wx_drag_over ( self, x, y, data, drag_result ):
+    def wx_drag_over(self, x, y, data, drag_result):
         """ Handles a Python object being dragged over the tree.
         """
-        return self._drag_event( 'drag_over', x, y, data, drag_result )
+        return self._drag_event('drag_over', x, y, data, drag_result)
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles a dragged Python object leaving the window:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def wx_drag_leave ( self, data ):
+    def wx_drag_leave(self, data):
         """ Handles a dragged Python object leaving the window.
         """
-        return self._drag_event( 'drag_leave' )
+        return self._drag_event('drag_leave')
 
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
     #  Handles routing a drag event to the appropriate handler:
-    #---------------------------------------------------------------------------
+    #-------------------------------------------------------------------------
 
-    def _drag_event ( self, suffix, x = None, y = None, data = None,
-                                    drag_result = None ):
+    def _drag_event(self, suffix, x=None, y=None, data=None,
+                    drag_result=None):
         """ Handles routing a drag event to the appropriate handler.
         """
         control = self.control
         handler = self.ui.handler
-        method  = None
+        method = None
 
-        owner   = getattr( control, '_owner', None )
+        owner = getattr(control, '_owner', None)
         if owner is not None:
-            method = getattr( handler, 'on_%s_%s' % ( owner.get_id(), suffix ),
-                              None )
+            method = getattr(handler, 'on_%s_%s' % (owner.get_id(), suffix),
+                             None)
 
         if method is None:
-            method = getattr( handler, 'on_%s' % suffix, None )
+            method = getattr(handler, 'on_%s' % suffix, None)
 
         if method is None:
             return wx.DragNone
 
         if x is None:
-            result = method( self.ui.info, owner )
+            result = method(self.ui.info, owner)
         else:
-            result = method( self.ui.info, owner, x, y, data, drag_result )
+            result = method(self.ui.info, owner, x, y, data, drag_result)
         if result is None:
             result = drag_result
         return result
 
-#-------------------------------------------------------------------------------
+
+#-------------------------------------------------------------------------
 #  Defines the extensions needed to make the generic Theme class specific to
 #  wxPython:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class WXTheme ( Category, Theme ):
+
+class WXTheme(Category, Theme):
     """ Defines the extensions needed to make the generic Theme class specific
         to wxPython.
     """
@@ -704,13 +691,13 @@ class WXTheme ( Category, Theme ):
     label_color = Property
 
     # The image slice used to draw the theme:
-    image_slice = Property( depends_on = 'image' )
+    image_slice = Property(depends_on='image')
 
-    #-- Property Implementations -----------------------------------------------
+    #-- Property Implementations ---------------------------------------------
 
-    def _get_content_color ( self ):
+    def _get_content_color(self):
         if self._content_color is None:
-            color  = wx.BLACK
+            color = wx.BLACK
             islice = self.image_slice
             if islice is not None:
                 color = islice.content_color
@@ -719,12 +706,12 @@ class WXTheme ( Category, Theme ):
 
         return self._content_color
 
-    def _set_content_color ( self, color ):
+    def _set_content_color(self, color):
         self._content_color = color
 
-    def _get_label_color ( self ):
+    def _get_label_color(self):
         if self._label_color is None:
-            color  = wx.BLACK
+            color = wx.BLACK
             islice = self.image_slice
             if islice is not None:
                 color = islice.label_color
@@ -733,38 +720,38 @@ class WXTheme ( Category, Theme ):
 
         return self._label_color
 
-    def _set_label_color ( self, color ):
+    def _set_label_color(self, color):
         self._label_color = color
 
     @cached_property
-    def _get_image_slice ( self ):
+    def _get_image_slice(self):
         from image_slice import image_slice_for
 
         if self.image is None:
             return None
 
-        return image_slice_for( self.image )
-
-#-------------------------------------------------------------------------------
+        return image_slice_for(self.image)
+#-------------------------------------------------------------------------
 #  Defines the extensions needed to make the generic DockWindowTheme class
 #  specific to wxPython:
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
-class WXDockWindowTheme ( Category, DockWindowTheme ):
+
+class WXDockWindowTheme(Category, DockWindowTheme):
     """ Defines the extensions needed to make the generic DockWindowTheme class
         specific to wxPython.
     """
 
     # The bitmap for the 'tab_inactive_edge' image:
-    tab_inactive_edge_bitmap = Property( depends_on = 'tab_inactive_edge' )
+    tab_inactive_edge_bitmap = Property(depends_on='tab_inactive_edge')
 
     # The bitmap for the 'tab_hover_edge' image:
-    tab_hover_edge_bitmap = Property( depends_on = 'tab_hover_edge' )
+    tab_hover_edge_bitmap = Property(depends_on='tab_hover_edge')
 
-    #-- Property Implementations -----------------------------------------------
+    #-- Property Implementations ---------------------------------------------
 
     @cached_property
-    def _get_tab_inactive_edge_bitmap ( self ):
+    def _get_tab_inactive_edge_bitmap(self):
         image = self.tab_inactive_edge
         if image is None:
             return None
@@ -772,7 +759,7 @@ class WXDockWindowTheme ( Category, DockWindowTheme ):
         return image.create_image().ConvertToBitmap()
 
     @cached_property
-    def _get_tab_hover_edge_bitmap ( self ):
+    def _get_tab_hover_edge_bitmap(self):
         image = self.tab_hover_edge
         if image is None:
             return self.tab_inactive_edge_bitmap
@@ -780,7 +767,7 @@ class WXDockWindowTheme ( Category, DockWindowTheme ):
         return image.create_image().ConvertToBitmap()
 
 
-#-------------------------------------------------------------------------------
+#-------------------------------------------------------------------------
 
 class EventHandlerWrapper(wx.EvtHandler):
     """ Simple wrapper around wx.EvtHandler used to determine which event
@@ -788,11 +775,12 @@ class EventHandlerWrapper(wx.EvtHandler):
     """
     pass
 
+
 def _popEventHandlers(ctrl):
     """ Pop any event handlers that have been pushed on to a window and its
         children.
     """
-    
+
     # Assume that all traitsui event handlers are on the top of the stack
     while ctrl is not ctrl.GetEventHandler():
         handler = ctrl.GetEventHandler()
